@@ -1,11 +1,24 @@
 # Install cron jobs.
 mkdir -p cron
-echo '#!/bin/bash
+
+if (( $(env | grep -c "CONDA_DEFAULT_ENV=" ) == 0 )) ; then
+    echo '#!/bin/bash
+. /home/nuwa/.bashrc
+conda activate /home/nuwa/app
+
+cd /home/nuwa/app/$APP_NAME
+
+{{ command|safe|escape }}
+' > cron/{{ jobName }}
+else
+    echo '#!/bin/bash
 source $HOME/app/bin/activate
 cd /home/nuwa/app/$APP_NAME
 
 {{ command|safe|escape }}
 ' > cron/{{ jobName }}
+fi
+
 sed -i -e "s#\$HOME#$HOME#g" cron/{{ jobName }}
 sed -i -e "s#\$PWD#$PWD#g" cron/{{ jobName }}
 chmod +x cron/{{ jobName }}
