@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: Util.py 11459 2019-04-16 18:20:57Z Lavender $
+# $Id: Util.py 11858 2020-01-12 11:45:03Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2019-04-17 03:20:57 +0900 (週三, 17 四月 2019) $
-# $Revision: 11459 $
+# $Date: 2020-01-12 20:45:03 +0900 (週日, 12 一月 2020) $
+# $Revision: 11858 $
 
 import sys
 import six
@@ -153,7 +153,7 @@ class ECPayShopShipment(object):
 
 def createCheckValue(data):
     data = OrderedDict(data)
-    data = OrderedDict(sorted(data.iteritems()))
+    data = OrderedDict(sorted(data.items()))
 
     orderedDict = OrderedDict()
     orderedDict['HashKey'] = settings.ECPAY_API_HASH_KEY
@@ -166,7 +166,11 @@ def createCheckValue(data):
     for k, v in orderedDict.items():
         dataList.append("%s=%s" % (k, v))
     dataStr = u"&".join(dataList)
-
-    encodeStr = urllib.urlencode({'data': utf8(dataStr),})[5:]
-    checkValue = hashlib.md5(encodeStr.lower()).hexdigest().upper()
+    
+    if six.PY2:
+        encodeStr = urllib.urlencode({'data': utf8(dataStr),})[5:]
+        checkValue = hashlib.md5(encodeStr.lower()).hexdigest().upper()
+    else:
+        encodeStr = urllib.parse.urlencode({'data': utf8(dataStr),})[5:]
+        checkValue = hashlib.md5(encodeStr.lower().encode()).hexdigest().upper()
     return checkValue
\ No newline at end of file
